@@ -6,6 +6,7 @@ from mwauth.base_auth import BaseAuth,User
 from flask import request,make_response,g,current_app,session
 from functools import wraps
 from .redis_session import RedisSessionInterface
+import hashlib
 class KongAuth(BaseAuth):
     # '''
     # 1，在request前提取 user info
@@ -105,5 +106,24 @@ class KongAuth(BaseAuth):
             return response
         return _request_login
 
+    def valid_sign(self,func):
+        @wraps(func)
+        def _request_sign(*args, **kw):
+            # json.dumps(json_body)+token+noncestr+timestamp 转md5
+            sign = request.headers.get('X-MW-Sign') or request.args.get("sign")
+            sign_source_str = f'{request.data.decode()}{g.jwt}' \
+                              f'{request.headers.get("X-MW-Noncestr") or request.args.get("noncestr", "")}' \
+                              f'{request.headers.get("X-MW-Timestamp") or request.args.get("timestamp", "")}'
+            sign_md5 = hashlib.md5(sign_source_str.encode()).hexdigest()
+            if sign_md5 == sign:
+                return func(*args, **kw)
+            # 没有认证则返回400
+            response = make_response({ "error": f'sign error,sign:{sign},noncestr:{request.args.get("noncestr", "")},'
+                                                f'timestamp:{request.args.get("timestamp", "")}'},
+                                     400, {"content-type": "application/json;charset=utf8"})
+            response.status_code = 400
+            return response
+        return _request_sign
+
 
 
